# optimal-pytorch

[![Build Status][build-image]][build-url]
[![codecov](https://codecov.io/gh/Nicolaus93/coin_betting/branch/master/graph/badge.svg)](https://codecov.io/gh/Nicolaus93/coin_betting)
[![Maintainability](https://api.codeclimate.com/v1/badges/62dcc62f012165d75a7f/maintainability)](https://codeclimate.com/github/Nicolaus93/coin_betting/maintainability)

...

<!-- Badges -->
[build-image]: https://github.com/Nicolaus93/coin_betting//workflows/build.yml/badge.svg
[build-url]: https://github.com/Nicolaus93/coin_betting/actions/workflows/build.yml

A library which combines Coin-Betting algorithms and test functions for optimization algorithms.
